@@ -5,7 +5,7 @@ from deezer.gw import GW
 from deezer.api import API
 from deezer.errors import DeezerError, WrongLicense, WrongGeolocation
 
-__version__ = "1.3.1"
+__version__ = "1.3.5"
 
 class TrackFormats():
     """Number associtation for formats"""
@@ -123,7 +123,8 @@ class Deezer:
                         'can_stream_hq': user_data["USER"]["OPTIONS"]["web_hq"] or user_data["USER"]["OPTIONS"]["mobile_hq"],
                         'can_stream_lossless': user_data["USER"]["OPTIONS"]["web_lossless"] or user_data["USER"]["OPTIONS"]["mobile_lossless"],
                         'country': user_data["USER"]["OPTIONS"]["license_country"],
-                        'language': user_data["USER"]["SETTING"]["global"]["language"]
+                        'language': user_data["USER"]["SETTING"]["global"]["language"],
+                        'loved_tracks': child.get("LOVEDTRACKS_ID")
                     })
         else:
             self.childs.append({
@@ -134,7 +135,8 @@ class Deezer:
                 'can_stream_hq': user_data["USER"]["OPTIONS"]["web_hq"] or user_data["USER"]["OPTIONS"]["mobile_hq"],
                 'can_stream_lossless': user_data["USER"]["OPTIONS"]["web_lossless"] or user_data["USER"]["OPTIONS"]["mobile_lossless"],
                 'country': user_data["USER"]["OPTIONS"]["license_country"],
-                'language': user_data["USER"]["SETTING"]["global"]["language"]
+                'language': user_data["USER"]["SETTING"]["global"]["language"],
+                'loved_tracks': user_data["USER"].get("LOVEDTRACKS_ID")
             })
 
     def change_account(self, child_n):
@@ -159,7 +161,7 @@ class Deezer:
             track_tokens = [track_tokens, ]
         if not self.current_user.get('license_token'):
             return []
-        if (track_format == "FLAC" or track_format.startswidth("MP4_RA")) and not self.current_user.get('can_stream_lossless') or track_format == "MP3_320" and not self.current_user.get('can_stream_hq'):
+        if (track_format == "FLAC" or track_format.startswith("MP4_RA")) and not self.current_user.get('can_stream_lossless') or track_format == "MP3_320" and not self.current_user.get('can_stream_hq'):
             raise WrongLicense(format)
 
         result = []
