@@ -5,33 +5,6 @@ import json
 from deezer.utils import map_artist_album, map_user_track, map_user_artist, map_user_album, map_user_playlist
 from deezer.errors import GWAPIError
 
-class LyricsStatus():
-    """Explicit Content Lyrics"""
-
-    NOT_EXPLICIT = 0
-    """Not Explicit"""
-
-    EXPLICIT = 1
-    """Explicit"""
-
-    UNKNOWN = 2
-    """Unknown"""
-
-    EDITED = 3
-    """Edited"""
-
-    PARTIALLY_EXPLICIT = 4
-    """Partially Explicit (Album "lyrics" only)"""
-
-    PARTIALLY_UNKNOWN = 5
-    """Partially Unknown (Album "lyrics" only)"""
-
-    NO_ADVICE = 6
-    """No Advice Available"""
-
-    PARTIALLY_NO_ADVICE = 7
-    """Partially No Advice Available (Album "lyrics" only)"""
-
 class PlaylistStatus():
     PUBLIC = 0
     PRIVATE = 1
@@ -54,11 +27,12 @@ class GW:
     def __init__(self, session, headers):
         self.http_headers = headers
         self.session = session
-        self.api_token = self._get_token()
+        self.api_token = None
 
     def api_call(self, method, args=None, params=None):
         if args is None: args = {}
         if params is None: params = {}
+        if not self.api_token and method != 'deezer.getUserData': self.api_token = self._get_token()
         p = {'api_version': "1.0",
              'api_token': 'null' if method == 'deezer.getUserData' else self.api_token,
              'input': '3',
@@ -87,6 +61,7 @@ class GW:
                     args[key] = result_json['payload']['FALLBACK'][key]
                 return self.api_call(method, args, params)
             raise GWAPIError(json.dumps(result_json['error']))
+        if not self.api_token and method == 'deezer.getUserData': self.api_token = result_json['results']['checkForm']
         return result_json['results']
 
     def _get_token(self):
@@ -397,6 +372,7 @@ class GW:
     def get_my_favorite_tracks(self, limit=25):
         ids_raw = self.get_user_favorite_ids(limit=limit)
         ids = [ x['SNG_ID'] for x in ids_raw['data'] ]
+        if len(ids) == 0: return []
         data = self.get_tracks(ids)
         result = []
         for (i, track) in enumerate(data):
